package com.fxy.putIn;

import android.annotation.SuppressLint;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.support.v7.widget.RecyclerView;
import android.text.Editable;
import android.text.TextWatcher;
import android.view.KeyEvent;
import android.view.View;
import android.view.inputmethod.EditorInfo;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.elvishew.xlog.XLog;
import com.fxy.R;
import com.fxy.baselibrary.base.BaseActivity;
import com.fxy.baselibrary.bean.BaseEventBusBean;
import com.fxy.baselibrary.interfaces.OnRxScanerListener;
import com.fxy.baselibrary.qrcode.ActivityScanerCode;
import com.fxy.baselibrary.util.JsonUtil;
import com.fxy.baselibrary.util.StringUtils;
import com.fxy.bean.ActionBean;
import com.fxy.bean.ScanBean;
import com.fxy.common.PictureSelectorUpload;
import com.fxy.constant.BaseConfig;
import com.fxy.constant.EventCode;
import com.fxy.net.MyDialogCallback;
import com.fxy.net.Urls;
import com.fxy.view.FloatingImageView;
import com.google.gson.Gson;
import com.google.zxing.Result;
import com.luck.picture.lib.config.PictureConfig;
import com.lzy.okgo.OkGo;
import com.lzy.okgo.model.Response;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;

import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;
import butterknife.Unbinder;
import sto.android.app.StoJNI;
import sto.android.app.StoPdaKeyEvent;
import sto.android.app.StoTongJNI;

public class PutinPalletMainActivity extends  BaseActivity implements StoJNI.ScanCallBack{

    /**
     * 列表适配器
     */
    Context mContext = this;

    //单号清除
    @BindView(R.id.ib_order_no_clear)
    ImageButton ibOrderNoClear;

    //单号
    @BindView(R.id.et_order_no)
    EditText etOrderNo;


    @BindView(R.id.ll_take_picture)
    LinearLayout llTakePicture;


    private ArrayList photoList =new ArrayList<>();

    private PictureSelectorUpload pictureSelectorUpload;
    //
    //扫码扫码动作
    private ScanBean scanBean;


    //浮动按钮
    @BindView(R.id.iv_drag)
    FloatingImageView iv_drag;



    protected String action;


    private Unbinder unbinder;

    private JSONObject postParam = new JSONObject();


    @Override
    public int getContentViewResId() {
        return R.layout.activity_fxy_putin_pallet;
    }

    @Override
    public boolean showToolBar() {
        return true;
    }

    @Override
    public boolean openEventBus() {
        return true;
    }

    @Override
    protected void getBundleExtras(Bundle bundle) {
        XLog.e("接收数据解析：",bundle);
        action = bundle.getString("action","add");
    }



    //finish的返回监听
    //这里的requestCode参数，就是上面设置的 1 ，当跳转的页面返回的时候，通过这个加以判断
    //resultCode ,这个参数是在跳转的页面里面规定的，它也是一个int类型的标志
    //第三个参数包含了返回的值
    //如果不需要所跳转的页面返回值，也就不需要这个方法了
    @Override
    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);

        if (resultCode == RESULT_OK) {
            if (requestCode == PictureConfig.CHOOSE_REQUEST) {// 图片选择结果回调
                pictureSelectorUpload.getSelectImg(data);
            }
        }
    }

    /**
     * EventBus接收信息的方法，开启后才会调用(非粘性事件)
     *
     * @param event
     */
    @Override
    protected void EventBean(BaseEventBusBean event) {
//        XLog.e("----------接收返回--------------");
//        XLog.e("接收返回："+event.getEventCode());
        if (event != null && event.getEventCode() == EventCode.displacement_refresh){

        }
    }

    @Override
    public boolean isPlayMusic() {
        return true;
    }


    @Override
    protected void initView() {
        unbinder = ButterKnife.bind(this);
        setTitleName("托盘入库");

        initEdit();
        iniData();

        RecyclerView rvShowImg = (RecyclerView)llTakePicture.findViewById(R.id.rv_show_img);
        pictureSelectorUpload  = setItemPicture("photo",rvShowImg,9,PictureConfig.TYPE_IMAGE);


        //监听浮动按钮
        iv_drag.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if(!iv_drag.isDrag()){
                    ActivityScanerCode.setScanerListener(mScanerListener);
                    ActivityScanerCode.intent2Activity(mContext, BaseConfig.COMMON_SCANNER_ONLY);
                }
            }
        });
    }



    /**
     * 设置多个上传文件
     * @param actionType String
     * @param showImg RecyclerView
     */
    private PictureSelectorUpload setItemPicture(String actionType,RecyclerView showImg,int maxNum,int pictureType){
        PictureSelectorUpload pictureUpload = new PictureSelectorUpload(PutinPalletMainActivity.this,showImg,"work",maxNum,pictureType);
        pictureUpload.setActionType(actionType);
        pictureUpload.setCompress(true,100,500);
        pictureUpload.setOnlyCamera(true);
        //showImg.onTouchEvent()

        pictureUpload.setOnChangeListener(new PictureSelectorUpload.UploadChangeListener() {
            @Override
            public void uploadResult(boolean State,String actionType) {
                if (State) {

                }
            }

            @Override
            public void uploadActionType(String actionType) {

                System.out.println("actionType："+actionType);

            }
        });
        return  pictureUpload;
    }


    @Override
    public boolean dispatchKeyEvent(KeyEvent event) {
        //XLog.e("event:"+event.getKeyCode());
        if ((event.getKeyCode()==KeyEvent.KEYCODE_DPAD_CENTER || event.getKeyCode()==KeyEvent.KEYCODE_ENTER )  && event.getAction() == KeyEvent.ACTION_DOWN){
            //按确定键
            if(this.validate()){
               pictureSelectorUpload.authCamera();
            }
        }
        return super.dispatchKeyEvent(event);
    }

    //监听按键
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        XLog.e("监听按键："+keyCode);XLog.e(event);
        if (scanBean.getIsBroadcast()==0 && StoTongJNI.getIns(mContext).getEventFuction(keyCode)  == StoPdaKeyEvent.KEYCODE_SCAN
                && event.getRepeatCount() == 0) {

            if (StoTongJNI.getIns(mContext).GetScannerIsScanning()) {
//
            } else {
                StoTongJNI.getIns(mContext).SetScannerStart();
            }
        }
        return super.onKeyDown(keyCode, event);
    }

    @SuppressLint("HandlerLeak")
    Handler scanHandler = new Handler() {

        @Override
        public void handleMessage(Message msg) {
            // TODO Auto-generated method stub
            if (msg.obj != null) {

                String scanResult = msg.obj.toString().trim();
                if (!scanResult.isEmpty()){
                    setScanResult(scanResult);
                }
            }

        }

    };
    @Override
    public void onScanResults(String str) {
        Message msg = new Message();
        msg.obj = str;
        scanHandler.sendMessage(msg);


    }


    @Override
    public void onScanResults(String str, int type) {

    }
    /**
     * 定义广播接受
     */
    BroadcastReceiver mReceiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            String scanResult = intent.getStringExtra(scanBean.getDataName());
            if (scanResult==null){return; }
            String scanStatus = "";
            if (!scanBean.getStatusName().isEmpty()){
                scanStatus = intent.getStringExtra(scanBean.getStatusName());
            }else{
                scanStatus = scanResult.isEmpty()? "" : "ok"; //有值 默认是扫码成功;
            }

            //新大陆(MT65,MT90) 需要手动关闭
            if (!scanBean.getActionStop().isEmpty()){
                Intent stopIntent = new Intent(scanBean.getActionStop());
                mContext.sendBroadcast(stopIntent);
            }

            if ("ok".equals(scanStatus)){
                setScanResult(scanResult);
            }else{
                showErrorToast(getString(R.string.scan_failed));
            }
        }
    };

    /**
     * 注册广播
     */
    private void initReceiver(){

        try {

            String scanStr = getScanSetting();
            scanBean = JsonUtil.getObject(scanStr, ScanBean.class);
            Integer is_broadcast = scanBean.getIsBroadcast();//是否广播

            if (is_broadcast ==1){
                IntentFilter mFilter = new IntentFilter(scanBean.getAction());
                this.registerReceiver(mReceiver, mFilter);
            }else{
                //不广播进行处理 jni模式
                String pdaBrand = StoTongJNI.getmPdaBrand();
                if (!pdaBrand.isEmpty()){
                    StoTongJNI.getIns(this).setmScanCB(this);
                    StoTongJNI.getIns(this).SetScannerOn();
                }
            }


        }catch (Exception e) {
            showErrorToast("获取扫码配置失败"+e.getMessage());
            XLog.e("获取扫码配置失败:" + e.getMessage());
        }
    }

    private void initEdit() {
        //
        etOrderNo.setOnEditorActionListener(new TextView.OnEditorActionListener() {
            @Override
            public boolean onEditorAction(TextView v, int actionId, KeyEvent event) {
                if (actionId == EditorInfo.IME_ACTION_DONE) {
                    String orderNo = etOrderNo.getText().toString().trim();
                    if (StringUtils.isEmpty(orderNo)) {
                        setEditTextFocused(v,true);
                        showWarningToast(v.getHint().toString());
                        return false;
                    }
                    pictureSelectorUpload.authCamera();
                    return false;
                }
                return false;
            }
        });
        etOrderNo.addTextChangedListener(new TextWatcher() {
            public void onTextChanged(CharSequence s, int start, int before, int count) {
                if (s.length() > 0 ) {
                    if (etOrderNo.isEnabled()){
                        ibOrderNoClear.setVisibility(View.VISIBLE);
                    }
                    setEditTextNormal(etOrderNo,true);
                } else {
                    ibOrderNoClear.setVisibility(View.INVISIBLE);
                    setEditTextFocused(etOrderNo,true);
                }
            }

            public void beforeTextChanged(CharSequence s, int start, int count, int after) {
            }

            public void afterTextChanged(Editable s) {

            }
        });
        ibOrderNoClear.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                etOrderNo.requestFocus();
                etOrderNo.getText().clear();
            }
        });
    }


    private void iniData(){

    }



    private OnRxScanerListener mScanerListener = new OnRxScanerListener() {
        @Override
        public void onSuccess(String type, Result result) {
            String scanResult = result.getText();
            switch (type){
                case BaseConfig.COMMON_SCANNER_ONLY:
                    setScanResult(scanResult);

                    break;
            }
        }
        @Override
        public void onFail(String type, String message) {

        }
    };

    //把扫描结果赋值
    private void setScanResult(String scanResult){
        //获取焦点的view对象
        View view=getWindow().getDecorView().findFocus();
        //如果是EditText
        if(view instanceof EditText)
        {
            ((EditText) view).setText(scanResult);

            switch (view.getId()) {
                case R.id.et_order_no:
                    pictureSelectorUpload.authCamera();
                    break;
                default:
            }


        }
    }


    private void pictureInbound(){
        if (!validate()){
            return;
        }


        if (!checkRepeat(Urls.FXY_BATCH_PICTURE_INBOUND+(postParam.toString()))){
            Toast.makeText(this, getString(R.string.error_data_processed), Toast.LENGTH_LONG).show();
            return;
        }



        OkGo.<String>post(Urls.getServiceAddress(this) + Urls.FXY_BATCH_PICTURE_INBOUND).upJson(postParam)
                .execute(new MyDialogCallback(this, true, true) {
                    @Override
                    public void onSuccess(Response<String> response) {
                        super.onSuccess(response);
                        try {
                            ActionBean bean = JsonUtil.getObject(response.body(), ActionBean.class);
                            if(bean.code == 1){
                                showSuccessToast(bean.msg);
                                pictureSelectorUpload.emptyRemake();//清空图片
                                photoList.clear();
                                etOrderNo.setText("");

                            }else{
                                showWarningToast(bean.msg);
                            }
                        } catch (Exception e) {
                            e.printStackTrace();
                            XLog.e("添加理货数据结果返回错误",e.getMessage());
                        }
                    }
                });
    }


    /*
     * 校验必录
     */
    private boolean validate(){
        photoList = pictureSelectorUpload.getPhotoList();
        //数据检查不通过
        String orderNo = etOrderNo.getText().toString().trim();
        if (orderNo.isEmpty()){
            showWarningToast(etOrderNo.getHint().toString());
            return false;
        }
        try {




            postParam = new JSONObject();

            //检查是否拍照  工单处理时拍照拍照非必传
            if (photoList.size()==0){
                showWarningToast("请拍照上传");
                return false;
            }
            Gson gson = new Gson();
            postParam.put("photo",gson.toJson(photoList));
            postParam.put("tracking_number",orderNo);

        } catch (JSONException e) {
            showWarningToast("系统异常"+e.getMessage());
            e.printStackTrace();
            return false;
        }



        return true;
    }

    //sIsGoodinfoMatch,sIsBattery,sIsMagnetic,sIsWood,sIsExtra,sIsOther
    @OnClick({R.id.btn_confirm,R.id.btn_photos})
    public void onViewClicked(View view) {
        Bundle bundle = new Bundle();
        switch (view.getId()) {
            case R.id.btn_photos:
                pictureSelectorUpload.authCamera();
                break;
           case R.id.btn_confirm:
                pictureInbound();
                break;
            default:
                break;
        }
    }

    @Override
    protected void onDestroy() {
        unbinder.unbind();
        pictureSelectorUpload.removeHandler();
        super.onDestroy();
    }
    @Override
    protected void onResume() {
        super.onResume();
        initReceiver();
    }
    @Override
    protected void onPause() {
        super.onPause();
        //销毁在onResume()方法中的广播
        try {
            //停止扫描
            Integer is_broadcast = scanBean.getIsBroadcast();//是否广播
            if (is_broadcast==0){
                StoTongJNI.getIns(mContext).SetScannerStop();
                StoTongJNI.getIns(mContext).SetScannerOff();
            }else{
                unregisterReceiver(mReceiver);
            }
        }catch (Exception e){
            XLog.e("销毁广播失败：",e.getMessage());
        }
    }

}
